@@ -630,8 +630,21 @@ extern void libGAP_syWinPut (
     const libGAP_Char *        cmd,
     const libGAP_Char *        str );
 
+/***************************************************************************
+ **
+ *F SyReadStringFid( <fid> )
+ **   - read file given by <fid> into a string
+ *F SyReadStringFile( <fid> )
+ **   - read file given by <fid> into a string, only rely on read()
+ *F SyReadStringFileStat( <fid> )
+ **   - read file given by <fid> into a string, use stat() to determine
+ **     size of file before reading. This does not work for pipes
+ */
+
+extern libGAP_Obj libGAP_SyReadStringFid(libGAP_Int fid);
+extern libGAP_Obj libGAP_SyReadStringFile(libGAP_Int fid);
+extern libGAP_Obj libGAP_SyReadStringFileGeneric(libGAP_Int fid);
 
-     
 /****************************************************************************
 **
 
